@@ -90,18 +90,21 @@ try
     {
         {"optional", Arg::Optional},
         {"extra", Arg::Required},
+        {"none", Arg::None},
         {"file", 'f'},
         {"version", 'v'},
         {"add", 'a'}
     };
     try
     {    
-        Arg::initialize("abcd:e:f:hv", 
-                lo, lo + 5,
+        Arg::initialize('t', "+abcd:e:f:hvt", 
+                lo, lo + 6,
                 argc, argv);
 
         Arg &arg = Arg::instance();
 
+        cout << "dashed options start at index " << arg.beyondDashes() << endl;
+
         arg.versionHelp(usage, "0.00", 1);
 
         for_each("abcdefg", "abcdefg" + 7, optcheck)
@@ -116,6 +119,7 @@ try
         longopt("extra");
         longopt("file");
         longopt("add");
+        longopt("none");
     }
     catch (exception const &e)
     {
@@ -123,7 +127,6 @@ try
     }
 
 }
-
 catch (int x)
 {
     cout << "int exception caught, value = " << x << '\n';
