@@ -1,6 +1,6 @@
 #include "bigint.ih"
 
-BigInt const BigInt::addModc(BigInt const &rhs, BigInt const &mod) const
+BigInt BigInt::addModc(BigInt const &rhs, BigInt const &mod) const
 {
     BigInt ret(*this);
     ret.addMod(rhs, mod);
