@@ -5,6 +5,6 @@ void BigInt::checked3(BIGNUM *div, BIGNUM *rem,
 {
     BNCTX ctx;
   
-    if (BN_div(div, rem, &d_bn, &rhs.d_bn, ctx) != 1)
-        throw Exception() << "BigInt " << op << " failed";
+    if (BN_div(div, rem, d_bn, rhs.d_bn, ctx) != 1)
+        throw Exception{} << "BigInt " << op << " failed";
 }
