@@ -1,6 +1,6 @@
 #include "bigint.ih"
 
-BigInt const BigInt::mulModc(BigInt const &rhs, BigInt const &mod) const
+BigInt BigInt::mulModc(BigInt const &rhs, BigInt const &mod) const
 {
     BigInt ret(*this);
     ret.mulMod(rhs, mod);
