@@ -1,6 +1,6 @@
 #include "bigint.ih"
 
-BigInt const BigInt::negatec() const
+BigInt BigInt::negatec() const
 {
     BigInt ret(*this);
     ret.negate();
