@@ -3,7 +3,7 @@
 int ClientSocket::connect()
 {
     if (::connect(socket(), sockaddrPtr(), size()) < 0)
-        throw Exception() << "ClientSocket::connect(): " << errnodescr;
+        throw Exception{} << "ClientSocket::connect(): " << errnodescr;
 
     return socket();
 }
