@@ -1,8 +1,8 @@
 #include <iostream>
+#include <stream>
 #include <bobcat/clientsocket>
 #include <bobcat/ifdstream>
 #include <bobcat/ofdstream>
-#include <bobcat/a2x>
 
 using namespace std;
 using namespace FBB;
@@ -16,7 +16,7 @@ try
         return 1;
     }
 
-    size_t     port = A2x(argv[2]);
+    size_t     port = stoul(argv[2]);
     ClientSocket client(argv[1], port);
     int fd = client.connect();
     string line;
