@@ -4,7 +4,7 @@
 //                   trimmed text following key. initial ws before
 //                   key should not be specified: skipped by findKeyTail.
 
-string ConfigFile::findKeyTail(string const &keyPattern, size_t count)
+string ConfigFile::findKeyTail(string const &keyPattern, size_t count) const
 {
     return d_ptr->findKeyTail(keyPattern, count);
 }
