@@ -1,4 +1,4 @@
-template <Insertable Type>
+template <typename Type>
 CSVTabDef &CSVTabDef::insert(Type const &value)
 {
     std::ostringstream str;
