@@ -1,4 +1,4 @@
-template <Insertable Type>
+template <typename Type>
 inline CSVTabIns &operator<<(CSVTabIns &tab, Type const &value)
 {
     return tab.insert(value);
@@ -6,7 +6,7 @@ inline CSVTabIns &operator<<(CSVTabIns &tab, Type const &value)
 
         // this one is called from CSVTable::operator CSVTabIns():
         //
-template <Insertable Type>
+template <typename Type>
 inline CSVTabIns &operator<<(CSVTabIns &&tab, Type const &value)
 {
     return tab << value;
