@@ -2,5 +2,5 @@
 
 size_t EncryptBuf::ivLength() const
 {
-    return EVP_CIPHER_CTX_iv_length(d_pimpl->ctx);
+    return EVP_CIPHER_CTX_iv_length(d_ctx);
 }
