@@ -5,10 +5,10 @@ namespace FBB
 
 std::ostream &operator<<(std::ostream &out, HMacBuf const &digestbuf)
 {
-    OHexStreambuf ohex(out);
+    OHexBuf ohex(out);
     ostream outs(&ohex);
-    outs.write(digestbuf.d_pimpl->digest.data(), 
-               digestbuf.d_pimpl->digest.length());
+    outs.write(digestbuf.d_digest.data(), 
+               digestbuf.d_digest.length());
     return out;
 }
 
