@@ -1,4 +1,4 @@
 inline void IOStream::open(std::istream &in, std::ostream &out)
 {
-    IOStreambuf::open(in, out);
+    IOBuf::reset(in, out);
 }
