@@ -7,7 +7,7 @@ namespace FBB
         if (called)
             return;
     
-        cerr << "[Warning] " << msg << 
+        cerr << "\n[Warning] " << msg << 
             " is deprecated.\n"
             "Avoid its use, see the man-page for alternatives.\n";
         called = true;
