@@ -1,8 +1,8 @@
 //  iterator insert(iterator pos, value_type const &keyValue);
 
-template <typename Key, typename Value, typename Alloc>
-typename LinearMap<Key, Value, Alloc>::iterator
-    LinearMap<Key, Value, Alloc>::insert(iterator pos, 
+template <typename Key, typename Value>
+typename LinearMap<Key, Value>::iterator
+    LinearMap<Key, Value>::insert(iterator pos, 
               value_type const &keyvalue)
 {
     auto iter = find(keyvalue.first);
