@@ -1,4 +1,4 @@
 inline void  Log::off()
 {
-    setActive(false);
+    setActive(OFF);
 }
