@@ -13,11 +13,12 @@ std::ostream &operator<<(std::ostream &str, LogManipulator manipulator)
 
         case nl:
             str << static_cast<char>(0);    // 0-char is interpreted by
-                                            // LogBuffer as '\n', without
+                                            // LogBuf as '\n', without
         break;                              // timestamp writing request.
 
-        default:                            // fnl not used. This 
-        break;                              // prevents the 'not used' warning
+        case fnl:
+            str << static_cast<char>(1);
+        break;
     }
     return str;
 }
