@@ -3,5 +3,5 @@
 void Mbuf::inspectOfstr(string const &name) const
 {
     if (not d_ofstr->good())
-        throw Errno(1) << "Can't write `" << name << '\''; 
+        throw Exception{1} << "Can't write `" << name << '\''; 
 }
