@@ -4,8 +4,13 @@
 //          the last element of a state cluster is the default transition.
 //          its 0-value will be overwritten by the conversion.
 //
+//  PerlSetFSA::convert (convert.cc) converts the received regular expression
+//  to a regcomp-compilable regex.
+
 PerlSetFSA::TransitionMatrix PerlSetFSA::s_stateTransitions[] =
 {
+//   d_state            d_input d_next              d_action
+
     {Start,             '\\',   Bs,                 &PerlSetFSA::nop    },
     {Start,             '[',    Set,                &PerlSetFSA::copy   },
     {Start,             0,      Start,              &PerlSetFSA::copy   },
@@ -18,43 +23,18 @@ PerlSetFSA::TransitionMatrix PerlSetFSA::s_stateTransitions[] =
     {Bs,                'W',    Start,              &PerlSetFSA::W_Set  },
     {Bs,                0,      Start,              &PerlSetFSA::copybs },
 
-    {Set,               '^',    NegatedSet,         &PerlSetFSA::copy   },
     {Set,               '\\',   SetBs,              &PerlSetFSA::nop    },
-    {Set,               '[',    NestedSet,          &PerlSetFSA::copy   },
     {Set,               0,      InsideASet,         &PerlSetFSA::copy   },
 
-    {NegatedSet,        '\\',   NegatedSetBs,       &PerlSetFSA::nop    },
-    {NegatedSet,        '[',    NegatedNestedSet,   &PerlSetFSA::copy   },
-    {NegatedSet,        0,      InsideANegatedSet,  &PerlSetFSA::copy   },
-
-    {NegatedSetBs,      'd',    NegatedSet,         &PerlSetFSA::d_Nest },
-    {NegatedSetBs,      's',    NegatedSet,         &PerlSetFSA::s_Nest },
-    {NegatedSetBs,      'w',    NegatedSet,         &PerlSetFSA::w_Nest },
-    {NegatedSetBs,      '\\',   NegatedSet,         &PerlSetFSA::copy   },
-    {NegatedSetBs,      ']',    Start,              &PerlSetFSA::copy   },
-    {NegatedSetBs,      0,      NegatedSet,         &PerlSetFSA::copybs },
-
-    {InsideANegatedSet, ']',    Start,              &PerlSetFSA::copy   },
-    {InsideANegatedSet, '[',    NegatedNestedSet,   &PerlSetFSA::copy   },
-    {InsideANegatedSet, '\\',   NegatedSetBs,       &PerlSetFSA::nop    },
-    {InsideANegatedSet, 0,      NegatedNestedSet,   &PerlSetFSA::copy   },
-
-    {NegatedNestedSet,  ']',    InsideANegatedSet,  &PerlSetFSA::copy   },
-    {NegatedNestedSet,  0,      NegatedNestedSet,   &PerlSetFSA::copy   },
-
-    {InsideASet,        '[',    NestedSet,          &PerlSetFSA::copy   },
-    {InsideASet,        ']',    Start,              &PerlSetFSA::copy   },
-    {InsideASet,        '\\',   SetBs,              &PerlSetFSA::nop    },
-    {InsideASet,        0,      InsideASet,         &PerlSetFSA::copy   },
-
     {SetBs,             'd',    InsideASet,         &PerlSetFSA::d_Nest },
     {SetBs,             's',    InsideASet,         &PerlSetFSA::s_Nest },
     {SetBs,             'w',    InsideASet,         &PerlSetFSA::w_Nest },
     {SetBs,             '\\',   InsideASet,         &PerlSetFSA::copy   },
     {SetBs,             0,      InsideASet,         &PerlSetFSA::copybs },
 
-    {NestedSet,         ']',    InsideASet,         &PerlSetFSA::copy   },
-    {NestedSet,         0,      NestedSet,          &PerlSetFSA::copy   },
+    {InsideASet,        ']',    Start,              &PerlSetFSA::copy   },
+    {InsideASet,        '\\',   SetBs,              &PerlSetFSA::nop    },
+    {InsideASet,        0,      InsideASet,         &PerlSetFSA::copy   },
 };
 
 PerlSetFSA::TransitionMatrix *PerlSetFSA::s_stateTransitions_end = 
