@@ -4,7 +4,7 @@ Pattern::Regex::Regex(string pattern, int options)
 :
     d_referenceCount(1)
 {    
-    PerlSetFSA().convert(pattern);
+    PerlSetFSA{}.convert(pattern);
 
     int errcode = regcomp(&d_regex, pattern.c_str(), options);
 
