@@ -1,6 +1,6 @@
 #include "process.ih"
 
-size_t Process::whichStream()
+Process::ChildOutput Process::whichStream()
 {
     d_selector.wait();
 
@@ -18,7 +18,7 @@ size_t Process::whichStream()
         return CHILD_COUT | CHILD_CERR;
 
         default:
-            throw Exception() << "Process::whichStream(): internal error. "
+            throw Exception{} << "Process::whichStream(): internal error. "
                                         "d_selector.nReady() returns " << 
                          count << " (should be <= 2)";
     }
