@@ -4,6 +4,14 @@ int Selector::wait()
 {
     timeval t = d_alarm;
 
+    if (                                    // no fd available and no waiting
+                                            // time
+        isEmpty(d_read) and isEmpty(d_write) and isEmpty(d_except) 
+        &&
+        t.tv_sec == -1 && t.tv_usec == -1
+    )
+        return 0;
+
     d_ret_read = d_read;
     d_ret_write = d_write;
     d_ret_except = d_except;
