@@ -1,7 +1,7 @@
 #include "syslogbuf.ih"
 
-Syslogbuf::~Syslogbuf()
+SyslogBuf::~SyslogBuf()
 {
-    close();
+//    eoi();
 }
     
