@@ -1,9 +1,9 @@
 #include "syslogbuf.ih"
 
-int Syslogbuf::overflow(int ch)
+int SyslogBuf::overflow(int ch)
 {
     if (ch != EOF)
-        d_data->buffer += ch;
+        buffer() += ch;
     else
         sync();
 
