@@ -1,4 +1,4 @@
 inline Priority SyslogStream::priority()   const       
 {
-    return Syslogbuf::priority();
+    return SyslogBuf::priority();
 }
