@@ -1,4 +1,4 @@
 inline Priority SyslogStream::setDefaultPriority(Priority priority)
 {
-    return Syslogbuf::setDefaultPriority(priority);
+    return SyslogBuf::setDefaultPriority(priority);
 }        
